#!/usr/bin/env python
#
# AppTool
# Copyright (C) 2010  Nathan Forbes
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys

import backup
import restore

class Color:
  bold = "\033[1;1m"
  green = "\033[1;32m"
  cyan = "\033[1;36m"
  yellow = "\033[1;33m"
  red = "\033[1;31m"
  off = "\033[1;0m"

def usage():
  usage = """
    usage: apptool {backup|restore}

    backup    Backup Apps
    restore   Restore Apps
    help      This help
          """
  print usage

def success(msg):
  if os.name == 'nt':
    print msg
  else:
    print Color.cyan + "==> " + Color.off + Color.bold + msg + Color.off

def message(msg):
  if os.name == 'nt':
    print msg
  else:
    print Color.green + "==> " + Color.off + Color.bold + msg + Color.off

def warning(msg):
  if os.name == 'nt':
    print msg
  else:
    print Color.yellow + "==> " + Color.off + Color.bold + msg + Color.off

def error(err):
  if os.name == 'nt':
    print >>sys.stderr, err
  else:
    print >>sys.stderr, Color.red + "==> " + Color.off + Color.bold + err + Color.off
  sys.exit(1)

def parseArgs(argv):
  if len(argv) < 2:
    return error("Not enough arguments")
  if len(argv) > 2:
    return error("Too many arguments")
  if argv[1] == 'help':
    return usage()
  elif argv[1] == 'backup':
    return backup.backupApps()
  elif argv[1] == 'restore':
    return restore.restoreApps()
  else:
    return error("`%s' not recognized" % argv[1])
